<?php

namespace sisAbaco\Http\Controllers;

use Illuminate\Http\Request;

use sisAbaco\CajaChica;
use Illuminate\Support\Facades\Redirect;
use sisAbaco\Http\Requests\CajaChicaFormRequest;
use DB;

use Carbon\Carbon;
use Fpdf;

class CajaChicaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
        $hoy = Carbon::now();
        $sum_abonos = DB::table('caja_chica')
        ->select(DB::raw('SUM(If(CJCtipMov="ABONO",CJCmonto,-1*CJCmonto)) as Total_Abonos'))
        ->get();
    	if ($request) {
    		$query = trim($request->get('tipo'));
            $desde = $request->get('desde');
            $hasta = $request->get('hasta');
    		$cajas_chi = DB::table('caja_chica')
            ->where('CJCtipMov','LIKE','%'.$query.'%')
            ->whereBetween('CJCfechaM',[$desde,$hasta])
    		->orderBy('idCaja_Chica','desc')
    		->paginate(7);
    		return view('inmobiliaria.caja_chica.index',["cajas_chi"=>$cajas_chi,"tipo"=>$query,"desde"=>$desde,"hasta"=>$hasta,"fecha_hoy"=>$hoy],["sum_abonos"=>$sum_abonos]);
    	}
    }

    public function create()
    {
        $caja_chica = DB::table('caja_chica')
            ->select(DB::raw('SUM(If(CJCtipMov="ABONO",CJCmonto,-1*CJCmonto)) as Total_Abonos'))
            ->get();
        $hoy = Carbon::now();
        return view("inmobiliaria.caja_chica.create",["caja_chica"=>$caja_chica],["fecha_hoy"=>$hoy]);
    }

    public function store(CajaChicaFormRequest $request)
    {
        $date = Carbon::now('America/Lima');
        $caja_chica = new CajaChica;
        $caja_chica->CJCfechaM=$date->toDateString();
        $caja_chica->CJChoraM=$date->toTimeString();
        $caja_chica->CJCtipMov="CARGO";
        $caja_chica->CJCmonto=$request->get('monto');
        $caja_chica->CJCdescri=$request->get('descripcion');
        $caja_chica->CJCdetalle=strtoupper($request->get('detalle'));
        $caja_chica->save();
        return Redirect::to('inmobiliaria/caja_chica');
    }

    public function reporte(){
        //Obtenemos los registros
        $registros = DB::table('caja_chica')->orderBy('idCaja_Chica','desc')->get();
        $configuracion = DB::table('configuracion')->where('idConfiguracion','=','1')->get();

        $pdf = new Fpdf('L','cm','A4');
        $pdf::AddPage();
        $pdf::SetTextColor(35,56,113);
        $pdf::SetFont('Arial','B',15);
        $pdf::Cell(0,10,utf8_decode("MOVIMIENTOS EN CAJA CHICA"),0,"","C");
         
        $pdf::Ln();
        $pdf::Ln();
        $pdf::SetTextColor(255,255,255);  // Establece el color del texto 
        $pdf::SetFillColor(100, 100, 255); // establece el color del fondo de la celda 
        $pdf::SetFont('Arial','B',10); 
        //El ancho de las columnas debe de sumar promedio 190        
        $pdf::cell(15,8,utf8_decode("ID"),1,"","C",true);
        $pdf::cell(40,8,utf8_decode("FECHA Y HORA"),1,"","C",true);
        $pdf::cell(30,8,utf8_decode("TIPO"),1,"","C",true);
        $pdf::cell(25,8,utf8_decode("MONTO"),1,"","C",true);
        $pdf::cell(80,8,utf8_decode("DESCRIPCIÓN"),1,"","C",true);
         
        $pdf::Ln();
        $pdf::SetTextColor(0,0,0);  // Establece el color del texto 
        $pdf::SetFillColor(255, 255, 255); // establece el color del fondo de la celda
        $pdf::SetFont("Arial","",9);
         
        foreach ($registros as $reg)
        {
            $pdf::cell(15,6,utf8_decode($reg->idCaja_Chica),1,"","C",true);
            $pdf::cell(40,6,utf8_decode($reg->CJCfechaM."  ".$reg->CJChoraM),1,"","C",true);
            $pdf::cell(30,6,utf8_decode($reg->CJCtipMov),1,"","C",true);
            $pdf::cell(25,6,utf8_decode("S/. ".$reg->CJCmonto." "),1,"","R",true);
            $pdf::cell(80,6,utf8_decode($reg->CJCdescri),1,"","L",true);
            $pdf::Ln(); 
        }
        $pdf::Output();
        exit;
    }

}
