<?php

namespace sisAbaco\Http\Controllers;

use Illuminate\Http\Request;

use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Input;
use sisAbaco\Http\Requests\ProductoFormRequest;
use sisAbaco\Producto;
use DB;

use Fpdf;

class ProductoController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
    	if ($request) {
    		$query = trim($request->get('searchText'));
    		$productos = DB::table('productos as prod')
    		->join('proyectos as proy','prod.idProyecto','=','proy.idProyecto')
    		->select('prod.idProducto','proy.PYTnombre as proyecto','prod.PDTnombre','prod.PDTlargo','prod.PDTancho','prod.PDTmanzan','prod.PDTparReg','prod.PDTprecio','prod.PDTimagen','prod.PDTestado')
    		->where('prod.PDTnombre','LIKE','%'.$query.'%')
    		->orwhere('proy.PYTnombre','LIKE','%'.$query.'%')
    		->orderBy('prod.idProducto','desc')
    		->paginate(7);
    		return view('inmobiliaria.producto.index',["productos"=>$productos,"searchText"=>$query]);
    	}
    }

    public function create()
    {
    	$proyectos = DB::table('proyectos')->where('PYTestado','=','V')->get();
    	return view("inmobiliaria.producto.create",["proyectos"=>$proyectos]);
    }

    public function store(ProductoFormRequest $request)
    {
    	$producto = new Producto;
    	$producto->idProyecto=$request->get('idproyecto');
    	$producto->PDTtipPro=$request->get('tipo_prod');
    	$producto->PDTnombre=strtoupper($request->get('nombre'));
    	$producto->PDTlargo=$request->get('largo');
    	$producto->PDTancho=$request->get('ancho');
        $producto->PDTperime=$request->get('perimetro');
    	$producto->PDTmanzan=strtoupper($request->get('manzana'));
    	$producto->PDTlindFt=strtoupper($request->get('lind_frente'));
    	$producto->PDTlindDe=strtoupper($request->get('lind_der'));
    	$producto->PDTlindIz=strtoupper($request->get('lind_izq'));
    	$producto->PDTlindFd=strtoupper($request->get('lind_fondo'));
    	$producto->PDTparReg=strtoupper($request->get('part_reg'));
    	$producto->PDTprecio=$request->get('precio');
    	$producto->PDTestado='D';
    	if (Input::hasFile('imagen')) {
    		$file=Input::file('imagen');
    		$file->move(public_path().'/imagenes/productos/',$file->getClientOriginalName());
    		$producto->PDTimagen=$file->getClientOriginalName();
    	}
    	$producto->save();
    	return Redirect::to('inmobiliaria/producto');
    }

    public function show($id)
    {
        $productos=DB::table('productos')->where('idProducto','=',$id)->get();
        return view("inmobiliaria.venta.show",["productos"=>$productos]);
    }

    public function edit($id)
    {
    	$producto=Producto::findOrFail($id);
    	$proyectos=DB::table('proyectos')->where('PYTestado','=','V')->get();
    	return view("inmobiliaria.producto.edit",["producto"=>$producto,"proyectos"=>$proyectos]);
    }

    public function update(ProductoFormRequest $request,$id)
    {
    	$producto = Producto::findOrFail($id);
    	$producto->idProyecto=$request->get('idproyecto');
    	$producto->PDTtipPro=$request->get('tipo_prod');
    	$producto->PDTnombre=strtoupper($request->get('nombre'));
        $producto->PDTlargo=$request->get('largo');
        $producto->PDTancho=$request->get('ancho');
        $producto->PDTperime=$request->get('perimetro');
        $producto->PDTmanzan=strtoupper($request->get('manzana'));
        $producto->PDTlindFt=strtoupper($request->get('lind_frente'));
        $producto->PDTlindDe=strtoupper($request->get('lind_der'));
        $producto->PDTlindIz=strtoupper($request->get('lind_izq'));
        $producto->PDTlindFd=strtoupper($request->get('lind_fondo'));
        $producto->PDTparReg=strtoupper($request->get('part_reg'));
    	$producto->PDTprecio=$request->get('precio');
    	if (Input::hasFile('imagen')) {
    		$file=Input::file('imagen');
    		$file->move(public_path().'/imagenes/productos/',$file->getClientOriginalName());
    		$producto->PDTimagen=$file->getClientOriginalName();
    	}
    	$producto->update();
    	return Redirect::to('inmobiliaria/producto');
    }

    public function destroy($id)
    {
    	$producto = Producto::findOrFail($id);
    	$producto->delete();
    	return Redirect::to('inmobiliaria/producto');
    }

    public function reporte(){
         //Obtenemos los registros
         $registros = DB::table('productos as prod')
            ->join('proyectos as proy','prod.idProyecto','=','proy.idProyecto')
            ->orderBy('idProducto','desc')
            ->get();
        $configuracion = DB::table('configuracion')->where('idConfiguracion','=','1')->get();

         $pdf = new Fpdf('L','cm','A4');
         $pdf::AddPage();
         $pdf::SetTextColor(35,56,113);
         $pdf::SetFont('Arial','B',15);
         $pdf::Cell(0,10,utf8_decode("Lista de Productos Registrados "),0,"","C");
         
         $pdf::Ln();
         $pdf::Ln();
         $pdf::SetTextColor(0,0,0);  // Establece el color del texto 
         $pdf::SetFillColor(206, 246, 245); // establece el color del fondo de la celda 
         $pdf::SetFont('Arial','B',10); 
         //El ancho de las columnas debe de sumar promedio 190        
         $pdf::cell(20,8,utf8_decode("LOTE"),1,"","L",true);
         $pdf::cell(65,8,utf8_decode("PROYECTO"),1,"","L",true);
         $pdf::cell(30,8,utf8_decode("PARTIDA"),1,"","C",true);
         $pdf::cell(25,8,utf8_decode("AREA"),1,"","C",true);
         $pdf::cell(25,8,utf8_decode("PRECIO"),1,"","C",true);
         $pdf::cell(25,8,utf8_decode("ESTADO"),1,"","C",true);
         
         $pdf::Ln();
         $pdf::SetTextColor(0,0,0);  // Establece el color del texto 
         $pdf::SetFillColor(255, 255, 255); // establece el color del fondo de la celda
         $pdf::SetFont("Arial","",9);
         
         foreach ($registros as $reg)
         {
            $pdf::cell(20,6,utf8_decode($reg->PDTnombre),1,"","L",true);
            $pdf::cell(65,6,utf8_decode($reg->PYTnombre),1,"","L",true);
            $pdf::cell(30,6,utf8_decode($reg->PDTparReg),1,"","C",true);
            $pdf::cell(25,6,utf8_decode($reg->PDTlargo * $reg->PDTancho . ' metros'),1,"","C",true);
            $pdf::cell(25,6,utf8_decode("S/. ".$reg->PDTprecio." "),1,"","R",true);
            if ($reg->PDTestado=="V") {
                $pdf::cell(25,6,utf8_decode("VENDIDO"),1,"","C",true);
            }elseif ($reg->PDTestado=="D") {
                $pdf::cell(25,6,utf8_decode("DISPONIBLE"),1,"","C",true);
            }else
                $pdf::cell(25,6,utf8_decode("RESERVADO"),1,"","C",true);
            $pdf::Ln(); 
         }
         $pdf::Output();
         exit;
    }

}
