<?php

namespace sisAbaco\Http\Controllers;

use Illuminate\Http\Request;

use sisAbaco\Venta;
use Illuminate\Support\Facades\Redirect;
use sisAbaco\Http\Requests\VentaFormRequest;
use DB;

use Fpdf;
use Response;
use Illuminate\Support\Collection;

class VentasController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
    	if ($request) {
    		$query = trim($request->get('searchText'));
    		$ventas = DB::table('ventas as ven')
    		->join('productos as prod','prod.idProducto','=','ven.idProducto')
    		->join('interesados as cli','cli.idInteresado','=','ven.idInteresado')
    		->where('ven.VTAnumDoc','LIKE','%'.$query.'%')
    		->orwhere('ven.VTAtipPag','LIKE','%'.$query.'%')
    		->orderBy('ven.idVenta','desc')
    		->paginate(7);
    		return view('inmobiliaria.ventas.index',["ventas"=>$ventas,"searchText"=>$query]);
    	}
    }

    public function reporte(){
        //Obtenemos los registros
        $registros = DB::table('ventas as ven')
        ->join('productos as prod','prod.idProducto','=','ven.idProducto')
        ->orderBy('idVenta','desc')
        ->get();
        $configuracion = DB::table('configuracion')->where('idConfiguracion','=','1')->get();

        $pdf = new Fpdf('L','cm','A4');
        $pdf::AddPage();
        $pdf::SetTextColor(35,56,113);
        $pdf::SetFont('Arial','B',15);
        $pdf::Cell(0,10,utf8_decode("REPORTE DE VENTAS"),0,"","C");
         
        $pdf::Ln();
        $pdf::Ln();
        $pdf::SetTextColor(255,255,255);  // Establece el color del texto 
        $pdf::SetFillColor(100, 100, 255); // establece el color del fondo de la celda 
        $pdf::SetFont('Arial','B',10); 
        //El ancho de las columnas debe de sumar promedio 190        
        $pdf::cell(15,8,utf8_decode("ID"),1,"","C",true);
        $pdf::cell(20,8,utf8_decode("TIPO"),1,"","C",true);
        $pdf::cell(40,8,utf8_decode("NUM. DOCUMENTO"),1,"","C",true);
        $pdf::cell(20,8,utf8_decode("LOTE"),1,"","C",true);
        $pdf::cell(40,8,utf8_decode("FECHA VENTA"),1,"","C",true);
        $pdf::cell(30,8,utf8_decode("FORMA PAGO"),1,"","C",true);
        $pdf::cell(25,8,utf8_decode("MONTO"),1,"","C",true);
         
        $pdf::Ln();
        $pdf::SetTextColor(0,0,0);  // Establece el color del texto 
        $pdf::SetFillColor(255, 255, 255); // establece el color del fondo de la celda
        $pdf::SetFont("Arial","",9);
         
        foreach ($registros as $reg)
        {
            $pdf::cell(15,7,utf8_decode($reg->idVenta),1,"","C",true);
            $pdf::cell(20,7,utf8_decode($reg->VTAtipDoc),1,"","C",true);
            $pdf::cell(40,7,utf8_decode($reg->VTAnumSer. ' - '.$reg->VTAnumDoc),1,"","C",true);
            $pdf::cell(20,7,utf8_decode($reg->PDTnombre),1,"","C",true);
            $pdf::cell(40,7,utf8_decode($reg->VTAfechaV),1,"","C",true);
            if ($reg->VTAtipPag=="CON") {
                $pdf::cell(30,7,utf8_decode("CONTADO"),1,"","C",true);
            }else
                $pdf::cell(30,7,utf8_decode("CRÉDITO"),1,"","C",true);
            $pdf::cell(25,7,utf8_decode("S/. ".$reg->VTAmonTot." "),1,"","R",true);
            $pdf::Ln(); 
        }
        $pdf::Output();
        exit;
    }

    public function boleta($id){
         //Obtengo los datos
        $venta=DB::table('ventas as ven')
            ->join('interesados as cli','cli.idInteresado','=','ven.idInteresado')
            ->join('cuotas_pago as c_p','c_p.idVenta','=','ven.idVenta')
            ->where('ven.idVenta','=',$id)
            ->first();

        $detalles=DB::table('cuotas_pago')
            ->where('idVenta','=',$id)
            ->get();


        $pdf = new Fpdf();
        $pdf::AddPage();

        $pdf::SetTextColor(0,0,0);  // Establece el color del texto
        $pdf::SetFillColor(206, 246, 245); // establece el color del fondo de la celda
        $pdf::SetFont('Arial','B',15);

        //Inicio con el reporte
        $pdf::SetXY(140,30);
        $pdf::Cell(0,0,utf8_decode($venta->VTAtipDoc.": ".$venta->VTAnumSer." - ".$venta->VTAnumDoc));

        $pdf::SetFont('Arial','B',10);
        $pdf::SetXY(20,50);
        $pdf::Cell(0,0,utf8_decode("Cliente:"));
        $pdf::SetXY(40,50);
        $pdf::Cell(0,0,utf8_decode($venta->INTdatos));

        $pdf::SetXY(20,57);
        $pdf::Cell(0,0,utf8_decode("Direcciòn:"));
        $pdf::SetXY(40,57);
        $pdf::Cell(0,0,utf8_decode($venta->INTdirec));

        $pdf::SetXY(140,50);
        $pdf::Cell(0,0,utf8_decode("Fecha Venta:"));
        $pdf::SetXY(170,50);
        $pdf::Cell(0,0,substr("  ".$venta->VTAfechaV,0,12));

        $pdf::SetXY(140,57);
        $pdf::Cell(0,0,utf8_decode("Costo Lote:"));
        $pdf::SetXY(170,57);
        $pdf::Cell(0,0,utf8_decode("S/. ".$venta->VTAmonTot));
        $total=0;

        //Mostramos los detalles
        $y=89.2;

        $pdf::SetTextColor(0,0,0);  // Establece el color del texto
        $pdf::SetFillColor(206, 246, 245); // establece el color del fondo de la celda
        $pdf::SetFont('Arial','B',10);
        //El ancho de las columnas debe de sumar promedio 190
        $yI=81;
        $pdf::SetXY(35,$yI);
        $pdf::cell(30,9,utf8_decode("NUM CUOTA"),1,"","C",true);
        $pdf::cell(40,9,utf8_decode("MONTO CUOTA"),1,"","C",true);
        $pdf::cell(35,9,utf8_decode("FECHA VENC."),1,"","C",true);
        $pdf::cell(35,9,utf8_decode("ESTADO"),1,"","C",true);

        foreach($detalles as $det){
            $pdf::SetXY(35,$y);
            $pdf::cell(30,7,utf8_decode($det->CUOnumCuo),1,"","C",true);
            $pdf::cell(40,7,utf8_decode("S/. ".$det->CUOmonto),1,"","C",true);
            $pdf::cell(35,7,utf8_decode($det->CUOfchVnc),1,"","C",true);
            if ($det->CUOestado=="P") {
                $pdf::cell(35,7,utf8_decode("Pagó"),1,"","C",true);
            }else{
                $pdf::cell(35,7,utf8_decode("Debe"),1,"","C",true);
            }
            $total=$total+($det->CUOmonto);
            $y=$y+7;
        }

        $pdf::Output();
        exit;
    }
}
